function obj = IsaacDATA(varargin)
% @IsaacDATA : constructeur
%
% (Appeler en TRY-CATCH pour sortie en erreur d'execution)

%	obj = IsaacDATA(datatype,dataval,datainfo)
%		=> objet @IsaacDATA initialis
%
%	obj = IsaacDATA(dataval,datainfo)
%		=> objet @IsaacDATA initialis avec dtermination automatique du datatype
%
%	obj = IsaacDATA(filename)
%		=> objet @IsaacDATA lu dans un fichier
%
%	obj = IsaacDATA()
%		=> objet @IsaacDATA par dfaut
%			(non utilis mais obligatoire pour load si aucun objet cr prcdement)
%
%	- datatype	: type de donne
%	- datainfo	: chaine d'info ou '' si non dfini
%	- dataval	: valeur
%	- filename	: nom du fichier dans rpertoire courant ou nom complet
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

% 	datatype		: type de donne
%						- 'VALL'	: valeur logical
%						- 'TABL'	: matrice logical de dimensions quelconques
%						- 'VALN'	: valeur numrique
%						- 'TABN'	: matrice numrique de dimensions quelconques
%						- 'VALA'	: chane ASCII
%						- 'TABA'	: cell array de chanes ASCII de dimensions quelconques
%						- 'VALX'	: valeur de classe quelconque
%						- 'TABX'	: cell array de contenu et dimensions quelconques
%						- 'NFIC'	: nom complet d'un fichier
%						- 'LFIC'	: cell array {n,1} de noms de fichiers
%						- 'NREP'	: nom complet de rpertoire
%
%	dataclass	: classe matlab de dataval
%	datainfo    : descriptif (ASCII)
%	dataval		: valeur
%
%	version		: version de l'objet 

%---------------------------------------------------------------------------------------------------

objversion = 1;

%---------------------------------------------------------------------------------------------------

switch nargin
	case 3
		% Objet initialis
		obj.datainfo = char(varargin{3});
		if (size(obj.datainfo,1) > 1) || ~isa(obj.datainfo,'char')
			error('argument incorrect')
		end
		obj.datatype = varargin{1};
		obj.dataval = varargin{2};
		if ~IsaacCheckType(obj.datatype,obj.dataval)
			error('arguments incompatibles')
		end	
		obj.dataclass = class(obj.dataval);
		obj.version = objversion;
		obj = class(orderfields(obj),'IsaacDATA'); % orderfields car class est sensible  l'ordre
	case 2
		% Objet initialis avec dtermination automatique du datatype
		obj.datainfo = char(varargin{2});
		if (size(obj.datainfo,1) > 1) || ~isa(obj.datainfo,'char')
			error('argument incorrect')
		end	
		obj.dataval = varargin{1};
		obj.datatype = IsaacFindType(obj.dataval);
		obj.dataclass = class(obj.dataval);
		obj.version = objversion;
		obj = class(orderfields(obj),'IsaacDATA'); % orderfields car class est sensible  l'ordre
	case 1
		% Lecture dans un fichier
		try
			warning off
			var = load('-mat',varargin{1},'DATA'); % variable DATA dans le fichier
			warning on
			obj = var.DATA;
			if ~isa(obj,'IsaacDATA')
				% erreur affiche par loadobj
				error('pour provoquer le catch')
			end
		catch
			error('fichier invalide')
		end
	case 0
		% Objet par dfaut non utilis mais obligatoire
		obj = struct('datatype',{},'datainfo',{},'dataval',{},'dataclass',{}, ...
			'version',{});
		obj = class(orderfields(obj),'IsaacDATA'); % orderfields car class est sensible  l'ordre
	otherwise
		 error('nombre d''arguments incorrect')
end
