function ok = IsaacCheckType(datatype,dataval)
% Vrifie la compatibilit de datatype et de dataval
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

if verLessThan('matlab', '7.11') 
	% code pour MATLAB 2010a et antrieur
	test_mat = (ndims(dataval) == 2);                                                            %#ok
else
	% code pour MATLAB 2010b (7.11) et postrieur  
	test_mat = ismatrix(dataval);
end

switch datatype
	case 'VALL'
		ok = isequal(size(dataval),[1 1]) && isa(dataval,'logical');
	case 'TABL'
		ok = isa(dataval,'logical');
	case 'VALN' % autorise []
		ok = test_mat && (size(dataval,1) <= 1) && (size(dataval,2) <= 1) && isa(dataval,'numeric');
	case 'TABN'
		ok = isa(dataval,'numeric');
	case 'VALA' % autorise ''
		ok = test_mat && (size(dataval,1) <= 1) && isa(dataval,'char');
	case 'TABA'
		ok = iscellstr(dataval);                                                                  %#ok
	case 'VALX'
		ok = true;
	case 'TABX'
		ok = iscell(dataval);
	case 'NFIC'
		ok = (size(dataval,1) == 1) && isa(dataval,'char') && exist(dataval,'file');
		ok = ok && ~exist(dataval,'dir'); % exist(x,'file') donne true pour fichier ou dossier
	case 'LFIC'
		ok = iscellstr(dataval) && test_mat && (size(dataval,2) <= 1);                            %#ok
		if ok
			nb = size(dataval,1);
			for i = 1:nb
				if ~ IsaacCheckType('NFIC',dataval{i})
					ok = false;
					break
				end
			end	
		end
	case 'NREP'
		ok = (size(dataval,1) == 1) && isa(dataval,'char') && exist(dataval,'dir');
	otherwise
		error('type de donne inconnu ou non gr')
end