function [h,c] = IsaacHist3(d,limits)
% Histogramme multidimensionnel compact pour images uint8  3 composantes [0..255]
% (Cas particulier de histn)
% 	- sans valeurs nulles.
% 	- tri par algorithme de quicksort lexicographique sur 1..3 dimensions.
% 	- born ventuellement sur chacune des 3 dimensions.
% 
% Usage [h,c]=IsaacHist3(d,limits)
% 
% 	d		: tableau MxNx3 des donnes.
% 	limits	: matrice 3x3 :
%				- ligne1 : min des valeurs  prendre en compte pour chaque composante. 
%				- ligne2 : max des valeurs  prendre en compte pour chaque composante.  
%				- ligne3 : 1|0 selon que la composante est ou non une dimension de sortie.  
% 	h			: matrice LxP (1>=P>=3) de l'histogramme compact  L P-uplets tris.
% 	c			: matrice Lx1 des effectifs pour chaque P-uplet de h.
% 
% 	d,limits,h de type uint8, c de type double
% 	
% Si les valeurs de limits ne peuvent tres satisfaites, h et c retourns sont vides	
% 
% D'aprs la thse de Alain Clment (Universit d'Angers - juillet 2002)
%
% Algorithm for OpenIsaac
% version 1
%  2002-2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

if ismac  
	if verLessThan('matlab', '9.3') 
      % MATLAB 2017a et antrieur
      [h,c] = imhist3_mac2010b(d,limits);
   else
      % MATLAB 2017b (9.3) et postrieur
      [h,c] = imhist3_mac2017b(d,limits);
	end   
elseif ispc
	if verLessThan('matlab', '9.3') 
      % MATLAB 2017a et antrieur
      [h,c] = imhist3_win2013b(d,limits);
   else
      % MATLAB 2017b (9.3) et postrieur
      [h,c] = imhist3_win2017b(d,limits);
	end   
else
    error('mexfile inexistant')     
end
end
