function [bitclass,nbplans] = IsaacImgType(img)
% Dtermine nb bits et nb plans d'une matrice image non indexe
%
% - bitclass : classe du nombre de bits/pixel et /plan ou 0 si type non gr
% - nbplans	 : de 1  ISAACCONST.ImMaxZ ou 0 si type non gr
%
% bitclass :	0  = type non gr ou inconnu 
%              1  = logical
%              8  = uint8
%              16 = uint16
%              32 = single
%              64 = double
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

global ISAACCONST

if isempty(img)
	bitclass = 0;
	nbplans = 0;
	return
end	
switch ndims(img)
case 2
	nbplans = 1;
case 3
	nbplans = size(img,3);
	if (nbplans > ISAACCONST.ImMaxZ)
		bitclass = 0;
		nbplans = 0;
		return
	end	
otherwise
	bitclass = 0;
	nbplans = 0;
	return
end	
if isa(img,'logical')
	bitclass = 1;
elseif isa(img,'uint8')
	bitclass = 8;
elseif isa(img,'uint16')
	bitclass = 16;
elseif isa(img,'single')
	imin = min(min(min(img))); % pour nb plans >= 1
	imax = max(max(max(img))); % pour nb plans >= 1
	if (imin >= 0 && imax <= 1)
		bitclass = 32;
	else
		bitclass = 0;
	end	
elseif isa(img,'double')
	imin = min(min(min(img))); % pour nb plans >= 1
	imax = max(max(max(img))); % pour nb plans >= 1
	if (imin >= 0 && imax <= 1)
		bitclass = 64;
	else
		bitclass = 0;
	end	
else
	bitclass = 0;
end
