function obj = IsaacROI_add(obj,varargin)
% @IsaacROI : ajoute un ou plusieurs intervalles spatiaux ou valeurs
%
%	obj = IsaacROI_add(obj,propname1,val1,...,propnameN,valN)
%
% propname	val
% --------	---
% 'RoiSpa'	[xmin,xmax,ymin,ymax]
% 'RoiVal'	[v1min,v1max,...,vzmin,vzmax]
%
% OpenIsaac
%  2018 Alain Clment - Universit d'Angers

%---------------------------------------------------------------------------------------------------

% Copyright 2007 - 2018 Universit d'Angers - Author: Alain Clment
%
% This program is free software; you can redistribute it and/or modify it under the terms of the GNU
% General Public License as published by the Free Software Foundation; either version 3 of the
% License, or any later version. This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
% PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received
% a copy of the GNU General Public License along with this program; if not, write to the Free
% Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

%---------------------------------------------------------------------------------------------------

if (nargin < 3)
	error('nombre d''arguments incorrect')
end
propargin = varargin;
while (length(propargin) >= 2)
	propname = propargin{1};
	val = propargin{2};
	propargin = propargin(3:end);
	switch propname
		case 'RoiSpa'
			if (~isa(val,'double') || ~isequal(size(val),[1 4]) || ...
			    (val(1) < 1) || (val(2) > obj.ima_dimx) || (val(1) > val(2)) || ...
				 (val(3) < 1) || (val(4) > obj.ima_dimy) || (val(3) > val(4)))
				 	error('argument incorrect')
			else		
				obj.spa_nb = obj.spa_nb + 1;
				obj.spa_mat(obj.spa_nb,:) = val;
			end	
		case 'RoiVal'
			if (~isa(val,'double') || ~isequal(size(val),[1 2*obj.ima_dimz]))
				error('argument incorrect')
			end
			for i = 1:obj.ima_dimz
				if ((val(2*i-1) < 0) || (val(2*i-1) > val(2*i)) || (val(2*i) > obj.valmax))
					error('argument incorrect')
				end
			end
			obj.val_nb = obj.val_nb + 1;
			obj.val_mat(obj.val_nb,:) = val;
		otherwise
			error('argument incorrect')
	end
end
if ~isempty(propargin)
	error('nombre d''arguments incorrect')
end